@@ -1812,7 +1812,7 @@ static inline void trace_btree_path_free(struct btree_trans *trans, btree_path_i
 
 /* This part must be outside protection */
 #undef TRACE_INCLUDE_PATH
-#define TRACE_INCLUDE_PATH /usr/src/bcachefs-1.31.1/src/fs/bcachefs
+#define TRACE_INCLUDE_PATH .
 
 #undef TRACE_INCLUDE_FILE
 #define TRACE_INCLUDE_FILE trace
